==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/resources/kotlin/inputs/ExtendedLocationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.resources.kotlin.inputs

import com.pulumi.azurenative.resources.inputs.ExtendedLocationArgs.builder
import com.pulumi.azurenative.resources.kotlin.enums.ExtendedLocationType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Resource extended location.
 * @property name The extended location name.
 * @property type The extended location type.
 */
public data class ExtendedLocationArgs(
    public val name: Output<String>? = null,
    public val type: Output<Either<String, ExtendedLocationType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.resources.inputs.ExtendedLocationArgs> {
    override fun toJava(): com.pulumi.azurenative.resources.inputs.ExtendedLocationArgs =
        com.pulumi.azurenative.resources.inputs.ExtendedLocationArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ExtendedLocationArgs].
 */
@PulumiTagMarker
public class ExtendedLocationArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var type: Output<Either<String, ExtendedLocationType>>? = null

    /**
     * @param value The extended location name.
     */
    @JvmName("ggcmywtkmguxxnqy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("uooxbywimsfbrfqr")
    public suspend fun type(`value`: Output<Either<String, ExtendedLocationType>>) {
        this.type = value
    }

    /**
     * @param value The extended location name.
     */
    @JvmName("cehalekfxayxgltn")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("aveamcuotlpfbkdj")
    public suspend fun type(`value`: Either<String, ExtendedLocationType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("qjgsrcofghpfcfgb")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ExtendedLocationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("vyxqvgneyouklxso")
    public fun type(`value`: ExtendedLocationType) {
        val toBeMapped = Either.ofRight<String, ExtendedLocationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ExtendedLocationArgs = ExtendedLocationArgs(
        name = name,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/resources/kotlin/inputs/ExtendedLocationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.resources.kotlin.inputs

import com.pulumi.azurenative.resources.inputs.ExtendedLocationArgs.builder
import com.pulumi.azurenative.resources.kotlin.enums.ExtendedLocationType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Resource extended location.
 * @property name The extended location name.
 * @property type The extended location type.
 */
public data class ExtendedLocationArgs(
    public val name: Output<String>? = null,
    public val type: Output<Either<String, ExtendedLocationType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.resources.inputs.ExtendedLocationArgs> {
    override fun toJava(): com.pulumi.azurenative.resources.inputs.ExtendedLocationArgs =
        com.pulumi.azurenative.resources.inputs.ExtendedLocationArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ExtendedLocationArgs].
 */
@PulumiTagMarker
public class ExtendedLocationArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var type: Output<Either<String, ExtendedLocationType>>? = null

    /**
     * @param value The extended location name.
     */
    @JvmName("puwcjropscjdudrs")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("kymkbakkdnwxqkpr")
    public suspend fun type(`value`: Output<Either<String, ExtendedLocationType>>) {
        this.type = value
    }

    /**
     * @param value The extended location name.
     */
    @JvmName("evntyiwihkebsyrx")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("hwgslevctqofusim")
    public suspend fun type(`value`: Either<String, ExtendedLocationType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("fnmvydeiwraoxdaj")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ExtendedLocationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The extended location type.
     */
    @JvmName("imydpdalbgrtjfgh")
    public fun type(`value`: ExtendedLocationType) {
        val toBeMapped = Either.ofRight<String, ExtendedLocationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ExtendedLocationArgs = ExtendedLocationArgs(
        name = name,
        type = type,
    )
}
